@@ -1,10 +1,10 @@
 <?php
 /**
- * $Horde: nag/lib/prefs.php,v 1.3.10.4 2007/01/02 13:55:12 jan Exp $
+ * $Horde: nag/lib/prefs.php,v 1.3.10.6 2008/01/02 11:32:29 jan Exp $
  *
- * Copyright 2001-2007 Jon Parise <jon@horde.org>
+ * Copyright 2001-2008 The Horde Project (http://www.horde.org/)
  *
- * See the enclosed file COPYING for license information (GPL).  If you
+ * See the enclosed file COPYING for license information (GPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/gpl.html.
  */
 
@@ -24,7 +24,12 @@ function handle_tasklistselect($updated)
 
 function handle_showsummaryselect($updated)
 {
-    $summary_categories = Util::getFormData('summary_categories');
-    $GLOBAL['prefs']->setValue('summary_categories', $summary_categories);
+    $GLOBAL['prefs']->setValue('summary_categories', Util::getFormData('summary_categories'));
+    return true;
+}
+
+function handle_defaultduetimeselect($updated)
+{
+    $GLOBALS['prefs']->setValue('default_due_time', Util::getFormData('default_due_time'));
     return true;
 }
